package com.fs.wxUser.service;

import com.fs.common.core.domain.R;
import com.fs.qw.param.CompanyWxUserAddGroupParam;
import com.fs.wxUser.domain.CompanyWxUser;
import com.fs.wxUser.param.CompanyWxUserBindFsUserParam;
import com.fs.wxUser.param.CompanyWxUserParam;
import com.fs.wxUser.vo.CompanyWxUserVO;

import java.util.List;

/**
 * 个微用户Service接口
 *
 * @author fs
 * @date 2024-10-22
 */
public interface ICompanyWxUserService
{
    /**
     * 查询个微用户
     *
     * @param userId 个微用户主键
     * @return 个微用户
     */
    public CompanyWxUser selectCompanyWxUserByUserId(Long userId);

    /**
     * 查询个微用户列表
     *
     * @param companyWxUser 个微用户
     * @return 个微用户集合
     */
    public List<CompanyWxUser> selectCompanyWxUserList(CompanyWxUser companyWxUser);
    public List<CompanyWxUserVO> selectCompanyWxUserListVO(CompanyWxUserParam param);

    /**
     * 新增个微用户
     *
     * @param companyWxUser 个微用户
     * @return 结果
     */
    public int insertCompanyWxUser(CompanyWxUser companyWxUser);

    /**
     * 修改个微用户
     *
     * @param companyWxUser 个微用户
     * @return 结果
     */
    public int updateCompanyWxUser(CompanyWxUser companyWxUser);

    /**
     * 批量删除个微用户
     *
     * @param userIds 需要删除的个微用户主键集合
     * @return 结果
     */
    public int deleteCompanyWxUserByUserIds(Long[] userIds);

    /**
     * 删除个微用户信息
     *
     * @param userId 个微用户主键
     * @return 结果
     */
    public int deleteCompanyWxUserByUserId(Long userId);

    CompanyWxUser selectCompanyWxUserByWeixinId(String weixinId);

    R updateCompanyWxUserBindFsUser(CompanyWxUserBindFsUserParam param);
    R addGroup(CompanyWxUserAddGroupParam param);
    R delGroup(CompanyWxUserAddGroupParam param);
}
